@@ -13,7 +13,7 @@
 # limitations under the License.
 
 import sys
-from mock import patch, call, DEFAULT, Mock, PropertyMock
+from unittest.mock import patch, call, DEFAULT, Mock, PropertyMock
 import pytest
 from functools import partial
 
@@ -123,6 +123,9 @@ class TestValidateStep(StepTester):
 class TestMugcStep(StepTester):
 
     def test_run(self):
+        type(self.m_conf).function_prefix = PropertyMock(
+            return_value='foobar-'
+        )
         mock_pol1 = Mock(provider_name='foo')
         mock_pol2 = Mock(provider_name='aws')
         mock_pol3 = Mock(provider_name='azure')
@@ -149,8 +152,8 @@ class TestMugcStep(StepTester):
             call(
                 config_files=['custodian_rName.yml'],
                 regions=['rName'],
-                prefix='custodian-',
-                policy_regex='^custodian-.*',
+                prefix='foobar-',
+                policy_regex='^foobar\\-.*',
                 assume=None,
                 policy_filter=None,
                 log_group=None,
@@ -175,6 +178,9 @@ class TestMugcStep(StepTester):
         ]
 
     def test_dryrun(self):
+        type(self.m_conf).function_prefix = PropertyMock(
+            return_value='foobar-'
+        )
         mock_pol1 = Mock(provider_name='foo')
         mock_pol2 = Mock(provider_name='aws')
         mock_pol3 = Mock(provider_name='azure')
@@ -201,8 +207,8 @@ class TestMugcStep(StepTester):
             call(
                 config_files=['custodian_rName.yml'],
                 regions=['rName'],
-                prefix='custodian-',
-                policy_regex='^custodian-.*',
+                prefix='foobar-',
+                policy_regex='^foobar\\-.*',
                 assume=None,
                 policy_filter=None,
                 log_group=None,
@@ -618,11 +624,11 @@ class TestMailerStep(StepTester):
                 '%s.mailer_deploy.provision' % pbm, autospec=True
             ) as mock_prov:
                 with patch(
-                    '%s.functools.partial' % pbm, autospec=True
-                ) as mock_partial:
+                    '%s.session_factory' % pbm, autospec=True
+                ) as mock_sf:
                     with patch(
-                        '%s.session_factory' % pbm, autospec=True
-                    ) as mock_sf:
+                        '%s.functools.partial' % pbm, autospec=True
+                    ) as mock_partial:
                         mock_config.return_value = m_conf
                         mock_partial.return_value = m_partial
                         runner.MailerStep('rName', self.m_conf).run()
@@ -640,11 +646,11 @@ class TestMailerStep(StepTester):
                 '%s.mailer_deploy.provision' % pbm, autospec=True
             ) as mock_prov:
                 with patch(
-                    '%s.functools.partial' % pbm, autospec=True
-                ) as mock_partial:
+                    '%s.session_factory' % pbm, autospec=True
+                ):
                     with patch(
-                        '%s.session_factory' % pbm, autospec=True
-                    ):
+                        '%s.functools.partial' % pbm, autospec=True
+                    ) as mock_partial:
                         mock_config.return_value = m_conf
                         mock_partial.return_value = m_partial
                         runner.MailerStep('rName', self.m_conf).dryrun()
